:mod:`nolearn.model`
--------------------

.. warning::

   The nolearn.model module will be removed in nolearn 0.6.  If you
   want to continue to use this module, please consider copying the
   code into your own project.

.. automodule:: nolearn.model

  .. autoclass:: AveragingEstimator
     :show-inheritance:

  .. autoclass:: AbstractModel
